Done:

- [x] Add methods for appending the memory map
- [x] Make it possible to create string memory map from generator of strings batched
- [x] Implement Rust base
- [x] Move RaggedMemoryMap from dnn_cool to mmap_ninja

Things to do:

- [ ] Implement memory mapped sparse matrix
- [ ] Implement Rust numpy module
- [ ] Implement Rust string module
- [ ] Implement Java base
- [ ] Implement Java numpy module
- [ ] Implement Java string module


